@@ -1,7 +1,7 @@
 package modinstaller
 
 import (
-	"github.com/Masterminds/semver"
+	"github.com/Masterminds/semver/v3"
 	"github.com/turbot/steampipe/pkg/versionhelpers"
 )
 
